package ch.dvbern.stvbe.security.saml.filter;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import ch.dvbern.stvbe.security.saml.util.StringUtils;

/**
 * Servlet Filter, welcher auf die Seite zum Setzen des neuen Passwortes verweist, falls der aktuelle
 * Benutzer eine bestimmte Rolle hat 
 * @author gema
 */
public class PasswordExpirationFilter implements Filter {

	private static final String DEFAULT_PW_EXP_PAGE = "https://osspwmgr.be.ch/iisadmpwd/aexp2.asp";
	private static final String DEFAULT_PW_EXP_ROLE = "PasswordExpired";
	private static final Log log = LogFactory.getLog(PasswordExpirationFilter.class);
	
	private String passwordExpiredPage;
	private String passwordExpiredRole;
	
	public void init(FilterConfig conf) throws ServletException {
		// Seite fuer den Passwortwechsel
		passwordExpiredPage = conf.getInitParameter("password.expired.page");
		if (StringUtils.isEmpty(passwordExpiredPage)) {
			passwordExpiredPage = DEFAULT_PW_EXP_PAGE;
		}
		log.info("PasswordExpired Page: " + passwordExpiredPage);

		// Rolle fuer den Fall, dass das Passwort abgelaufen ist
		passwordExpiredRole = conf.getInitParameter("password.expired.role");
		if (StringUtils.isEmpty(passwordExpiredRole)) {
			passwordExpiredRole = DEFAULT_PW_EXP_ROLE;
		}
		log.info("PasswordExpired Role: " + passwordExpiredRole);
	}

	public void doFilter(ServletRequest request, ServletResponse response,
			FilterChain chain) throws IOException, ServletException {

		if (response instanceof HttpServletResponse) {
			HttpServletResponse httpResonse = (HttpServletResponse)response;
			HttpServletRequest httpRequest = (HttpServletRequest)request;
			
			if (httpRequest.isUserInRole(passwordExpiredRole)) {
				// Die Session wird geschlossen, damit sich der Benutzer neu anmelden muss.
				// im jboss-web.xml muss das Attribut flushOnSessionInvalidation des elements 
				// security-domain auf true gesetzt werden, damit nicht das alte Passwort
				// aus dem Credential Cache geloescht wird 
				// (siehe http://www.jboss.org/wiki/Wiki.jsp?page=CachingLoginCredentials)
				httpRequest.getSession(true).invalidate();
				
				// Redirect senden
				httpResonse.sendRedirect(passwordExpiredPage);
				return;
			}
		}

		chain.doFilter(request, response);

	}

	public void destroy() {
	}

}
