package ch.dvbern.stvbe.security.saml.filter;

import java.io.IOException;
import java.security.Principal;
import java.security.acl.Group;

import javax.security.auth.Subject;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletRequestWrapper;

import org.jboss.security.SecurityAssociation;

/**
 * Servlet Filter, welcher sicherstellt dass der Security Kontext 
 * korrekt propagiert wird 
 * @author gema
 */
public class SecurityContextFilter implements Filter {

	public void init(FilterConfig conf) throws ServletException {
	}

	public void doFilter(ServletRequest request, ServletResponse response,
			FilterChain chain) throws IOException, ServletException {

		if (request instanceof HttpServletRequest) {
			request = new SecurityAssociationAwareRequest((HttpServletRequest) request);
		}

		chain.doFilter(request, response);

	}

	public void destroy() {
	}

	/**
	 * Servlet Request, welcher mit der JBoss Security Association verknuepft ist
	 * @author gema
	 */
	private static class SecurityAssociationAwareRequest extends HttpServletRequestWrapper {
		/**
		 * Konstruktor
		 * @param request der Orginal Request
		 */
		public SecurityAssociationAwareRequest(HttpServletRequest request) {
			super(request);
		}

		@Override
		public Principal getUserPrincipal() {
			return SecurityAssociation.getCallerPrincipal();
		}

		@Override
		public String getRemoteUser() {
			Principal p = getUserPrincipal();
			if (p == null) {
				return null;
			} else {
				return p.getName();
			}
		}

		@Override
		public boolean isUserInRole(String arg0) {

			Subject subj = SecurityAssociation.getSubject();
			if (subj == null || subj.getPrincipals() == null) {
				return false;
			}

			for (Principal p : subj.getPrincipals()) {
				if (p instanceof Group && p.getName().endsWith(arg0)) {
					return true;
				}
			}
			return false;
		}
	}

}
