package ch.dvbern.stvbe.security.saml.handler;

import java.util.Map;
import java.util.Vector;

import org.apache.cxf.binding.soap.SoapMessage;
import org.apache.cxf.binding.soap.interceptor.AbstractSoapInterceptor;
import org.apache.cxf.interceptor.Fault;
import org.apache.cxf.phase.Phase;
import org.apache.ws.security.handler.WSHandlerConstants;
import org.apache.ws.security.handler.WSHandlerResult;
import org.codehaus.xfire.MessageContext;

import ch.dvbern.stvbe.security.saml.handler.extract.SamlAssertionExtractor;
import ch.dvbern.stvbe.security.saml.handler.extract.Wss4jAssertionExtractor;
import ch.dvbern.stvbe.security.saml.handler.util.SamlValidationException;
import ch.dvbern.stvbe.security.saml.handler.util.SamlValidationResult;
import ch.dvbern.stvbe.security.saml.handler.util.SamlValidationUtil;
import ch.dvbern.stvbe.security.saml.verify.SamlAssertionVerifier;
import ch.dvbern.stvbe.security.saml.verify.SamlAssertionVerifierFactory;

/**
 * SAML Validation Interceptor fuer Apache CXF
 * @author GEMA
 *
 */
public class CxfSamlValidationInterceptor extends AbstractSoapInterceptor{

	/**
	 * Name des Message Context Properties fuer den Principal Namen. Der Handler Legt den Principal
	 * Namen unter diesem Key im {@link MessageContext} ab.
	 * @see MessageContext
	 */
	public static final String PRINCIPAL_NAME_PROP = HandlerConstants.PRINCIPAL_NAME_PROP;

	/**
	 * Name des Message Context Properties fuer die SAML Assertion. Der Handler Legt die SAML Assertion
	 * unter diesem Key im {@link MessageContext} ab.
	 * @see MessageContext
	 */
	public static final String ASSERTION_PROP = HandlerConstants.ASSERTION_PROP;
	
	private SamlAssertionVerifier verifier;

	/**
	 * Konstruktor
	 */
	public CxfSamlValidationInterceptor() {
		super(Phase.PRE_PROTOCOL);
	}

	/**
	 * Konstruktor
	 * @param properties
	 */
	public CxfSamlValidationInterceptor(Map<String, String> properties) {
		this();
		setProperties(properties);
	}
	
	/**
	 * Setzt die Konfiguration
	 * @param config die Konfiguration
	 */
	public void setProperties(Map<String, String> config) {
		verifier = SamlAssertionVerifierFactory.getInstance().
			createVerifier(config);
	}


	/**
	 * Erstellt den Assertion Provider
	 * @param msg die SOAP Message 
	 * @return den Provider
	 */
	@SuppressWarnings("unchecked")
	protected SamlAssertionExtractor getAssertionProvider(SoapMessage msg) {
		Vector<WSHandlerResult> result = (Vector<WSHandlerResult>) msg.get(WSHandlerConstants.RECV_RESULTS);
		return new Wss4jAssertionExtractor(result);
	}

	public void handleMessage(SoapMessage msg) throws Fault {
		if (verifier == null) {
			throw new IllegalStateException("configuration not set");
		}
		
		try {
			SamlAssertionExtractor provider = getAssertionProvider(msg);
			SamlValidationResult result;
			result = SamlValidationUtil.validate(provider, verifier);

			msg.put(ASSERTION_PROP, result.getAssertion());
			msg.put(PRINCIPAL_NAME_PROP, result.getPrincipalName());
			
		} catch (SamlValidationException e) {
			throw new Fault(e);
		}
		
	}

}
