package ch.dvbern.stvbe.security.saml.handler;

import java.util.Properties;
import java.util.Vector;

import org.apache.ws.security.handler.WSHandlerConstants;
import org.apache.ws.security.handler.WSHandlerResult;
import org.codehaus.xfire.MessageContext;
import org.codehaus.xfire.handler.AbstractHandler;

import ch.dvbern.stvbe.security.saml.handler.extract.SamlAssertionExtractor;
import ch.dvbern.stvbe.security.saml.handler.extract.Wss4jAssertionExtractor;
import ch.dvbern.stvbe.security.saml.handler.util.SamlValidationResult;
import ch.dvbern.stvbe.security.saml.handler.util.SamlValidationUtil;
import ch.dvbern.stvbe.security.saml.verify.SamlAssertionVerifier;
import ch.dvbern.stvbe.security.saml.verify.SamlAssertionVerifierFactory;

/**
 * SAML Validierungs-Handler fuer XFire Web Services
 * @author GEMA
 */
public class XFireSamlValidationHandler extends AbstractHandler {

	private SamlAssertionVerifier verifier;

	/**
	 * Name des Message Context Properties fuer den Principal Namen. Der Handler Legt den Principal
	 * Namen unter diesem Key im {@link MessageContext} ab.
	 * @see MessageContext
	 */
	public static final String PRINCIPAL_NAME_PROP = HandlerConstants.PRINCIPAL_NAME_PROP;

	/**
	 * Name des Message Context Properties fuer die SAML Assertion. Der Handler Legt die SAML Assertion
	 * unter diesem Key im {@link MessageContext} ab.
	 * @see MessageContext
	 */
	public static final String ASSERTION_PROP = HandlerConstants.ASSERTION_PROP;
	
	/**
	 * Konstruktor
	 */
	public XFireSamlValidationHandler() {
	}

	/**
	 * Konstruktor
	 * @param config die Konfiguration
	 */
	public XFireSamlValidationHandler(Properties config) {
		setProperties(config);
	}

	/**
	 * Setzt die Konfiguration
	 * @param config die Konfiguration
	 */
	public void setProperties(Properties config) {
		verifier = SamlAssertionVerifierFactory.getInstance().
			createVerifier(config);
	}

	public void invoke(MessageContext context) throws Exception {
		if (verifier == null) {
			throw new IllegalStateException("configuration not set");
		}
		
		SamlAssertionExtractor provider = getAssertionProvider(context);
		SamlValidationResult result = SamlValidationUtil.validate(provider, verifier);
		
		context.setProperty(ASSERTION_PROP, result.getAssertion());
		context.setProperty(PRINCIPAL_NAME_PROP, result.getPrincipalName());
		
	}

	/**
	 * Erstellt den Assertion Provider
	 * @param context der Kontext
	 * @return den Provider
	 */
	@SuppressWarnings("unchecked")
	protected SamlAssertionExtractor getAssertionProvider(MessageContext context) {
		Vector<WSHandlerResult> result = (Vector<WSHandlerResult>) context
				.getProperty(WSHandlerConstants.RECV_RESULTS);
		return new Wss4jAssertionExtractor(result);
	}

}
