package ch.dvbern.stvbe.security.saml.handler.extract;

import java.util.Vector;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.ws.security.WSSecurityEngineResult;
import org.apache.ws.security.handler.WSHandlerResult;
import org.opensaml.SAMLAssertion;

/**
 * Extrahiert SAML Assertions aus dem WSS4J Kontext
 * @author GEMA
 */
public class Wss4jAssertionExtractor implements SamlAssertionExtractor {

	private static final Log log = LogFactory.getLog(Wss4jAssertionExtractor.class);
	
	private Vector<WSHandlerResult> result;

	/**
	 * Konstruktor
	 * @param results der Inhalt des WSS4J Kontext
	 */
	public Wss4jAssertionExtractor(Vector<WSHandlerResult> results) {
		this.result = results;
	}

	@SuppressWarnings("unchecked")
	public SAMLAssertion getSAMLAssertion() {
		if (result != null) {
			for (WSHandlerResult res : result) {
				Vector<WSSecurityEngineResult> secResults = res.getResults();
				for (WSSecurityEngineResult secRes : secResults) {
					SAMLAssertion assertion = secRes.getAssertion();
					if (assertion != null) {
						if (log.isDebugEnabled()) {
							log.debug("SAML Assertion found: " + assertion);
						}
						return assertion;
					}
				}
			}
		}
		
		
		log.debug("No SAML Assertion found");
		return null;
	}
}
