package ch.dvbern.stvbe.security.saml.handler.util;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.opensaml.SAMLAssertion;

import ch.dvbern.stvbe.security.saml.handler.extract.SamlAssertionExtractor;
import ch.dvbern.stvbe.security.saml.verify.SamlAssertionVerifier;
import ch.dvbern.stvbe.security.saml.verify.SamlAssertionVerifyerException;


/**
 * Hilfsklasser fuer SAML Validierungen
 * @author GEMA
 *
 */
public final class SamlValidationUtil {
	
	private static final Log log = LogFactory.getLog(SamlValidationUtil.class);
	
	private SamlValidationUtil() {
	}

	/**
	 * Fuehrt eine SAML Validierung durch. Die SAML Assertion wird mit dem Extractor ermittelt und 
	 * anschliessend durch den Verifier validiert.
	 * @param provider der Extraxtor
	 * @param verifier der Verifier
	 * @return das Resultat
	 * @throws SamlValidationException falls die SAML Validierung fehlschlaegt.
	 */
	public static SamlValidationResult validate(SamlAssertionExtractor provider, SamlAssertionVerifier verifier) throws SamlValidationException {
		if (provider == null) {
			throw new IllegalArgumentException("provider may not be null");
		}
		if (verifier == null) {
			throw new IllegalArgumentException("verifier may not be null");
		}
		
		try {
		
			// Extrahieren
			SAMLAssertion assertion = provider.getSAMLAssertion();
			if (log.isDebugEnabled()) {
				log.debug("SAML Assertion extracted: " + assertion);
			}

			// verifizieren
			verifier.verify(assertion);

			// Resultat erstellen
			return new SamlValidationResult(verifier.getUsername(assertion), assertion);
			
		} catch (SamlAssertionVerifyerException e) {
			log.debug("SAML Assertion invalid", e);
			throw new SamlValidationException("SAML Assertion invaild", e);
		}
	}
}
