package ch.dvbern.stvbe.security.saml.key;

import java.io.InputStream;
import java.security.PublicKey;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.Collections;
import java.util.Set;

/**
 * Implementation eines PublicKeyProviders, welche den {@link PublicKey} aus
 * einem als Resource geladenen {@link X509Certificate} holt.
 * 
 * @author beph
 * 
 */
public class ResourceX509CertificatePublicKeyProvider implements PublicKeyProvider {

	private String resourceName;

	/**
	 * Konstruktor
	 */
	public ResourceX509CertificatePublicKeyProvider() {
	}
	
	/**
	 * Konstruktor
	 * @param resourceName der Name der Zertifikatsdatei
	 */
	public ResourceX509CertificatePublicKeyProvider(String resourceName) {
		if (resourceName == null || resourceName.trim().length() == 0) {
			throw new IllegalArgumentException("certificate resource name may not be empty");
		}
		this.resourceName = resourceName;
	}
	
	/**
	 * Setzt den Namen der Zertifikatsdatei
	 * @param resourceName der Name
	 */
	public void setResourceName(String resourceName) {
		this.resourceName = resourceName;
	}
	
	private PublicKey getPublicKey() {
		if (resourceName == null) {
			throw new PublicKeyProviderException("resourceName not set");
		}
		
		if (!resourceName.startsWith("/")) {
			resourceName = "/" + resourceName;
		}
		
		InputStream input = getClass().getResourceAsStream(resourceName);
		if (input == null) {
			throw new PublicKeyProviderException("Cannot find resource: "
					+ resourceName);
		}
		try {
			X509Certificate cert = (X509Certificate) CertificateFactory
					.getInstance("X.509").generateCertificate(input);
			return cert.getPublicKey();
		} catch (CertificateException e) {
			throw new PublicKeyProviderException("Certificate corrupt!", e);
		}
	}

	public Set<PublicKey> getPublicKeys() {
	    return Collections.singleton(getPublicKey());
	}
}
