package ch.dvbern.stvbe.security.saml.util;

import java.util.Iterator;

import org.opensaml.SAMLAssertion;
import org.opensaml.SAMLAuthenticationStatement;
import org.opensaml.SAMLStatement;

/**
 * Hilfsklasse fuer SAML Assertions
 * @author gema
 *
 */
public class SamlAssertionUtil {
	
	
	private SamlAssertionUtil(){
	}
	
	/**
	 * Extrahiert die User ID aus dieser SAML Assertion
	 * @param assertion die SAML Assertion
	 * @return die User ID
	 */
	@SuppressWarnings("unchecked")
	public static String getUsername(SAMLAssertion assertion) {
		Validate.notNull(assertion, "SAML Assertion darf nicht null sein");
		
		for(Iterator<SAMLStatement> it = assertion.getStatements(); it.hasNext(); ) {
			SAMLStatement stmt = it.next();
			if (stmt instanceof SAMLAuthenticationStatement) {
				SAMLAuthenticationStatement auths = (SAMLAuthenticationStatement)stmt;
				if (auths.getSubject() != null && auths.getSubject().getNameIdentifier() != null) {
					return auths.getSubject().getNameIdentifier().getName();
				}
			}
		}
		
		return null;
	}

}
