package ch.dvbern.stvbe.security.saml.util;

/**
 * Utility class for Strings (not using commons-lang to reduce the dependencies). 
 * @author gema
 *
 */
public class StringUtils {

	/**
     * Constructor. This class should not be instantiated.
     */
	private StringUtils(){
	}
	
	/**
	 * Checks whether the passed string is <code>null</code> or empty
	 * @param value the String to check 
	 * @return <code>true</code> if the passed string is empty
	 */	
	public static boolean isEmpty(String value) {
		return value == null || value.trim().length() == 0;
	}

	/**
	 * Replace all occurrences of a substring within a string with another
	 * string.
	 * 
	 * @param inString
	 *            String to examine
	 * @param toReplace
	 *            String to replace
	 * @param replacement
	 *            String to insert
	 * @return a String with the replacements
	 */
	public static String replace(String inString, String toReplace, String replacement) {
		
		if (inString == null) {
			return null;
		}
		if (toReplace == null) {
			return inString;
		}
		if (replacement == null) {
			replacement = "";
		}
		
		StringBuilder sbuf = new StringBuilder();
		int pos = 0;
		int toReplLen = toReplace.length();
		int idx = inString.indexOf(toReplace);
		while(idx >= 0) {
			sbuf.append(inString.substring(pos, idx));
			sbuf.append(replacement);
			pos = idx + toReplLen;
			idx = inString.indexOf(toReplace, pos);
		}
		sbuf.append(inString.substring(pos));

		return sbuf.toString();
	}

}
