package ch.dvbern.stvbe.security.saml.util;


/**
 * Validation Utility (not using commons-lang to reduce the dependencies).
 */
@SuppressWarnings("unchecked")
public final class Validate
{
    /**
     * Constructor. This class should not be instantiated.
     */
    private Validate()
    {
        super();
    }

    // notNull
    // ---------------------------------------------------------------------------------

    /**
     * <p>
     * Validate an argument, throwing <code>IllegalArgumentException</code> if the argument is
     * <code>null</code>.
     * </p>
     * 
     * <pre>
     * Validate.notNull(myObject, &quot;The object must not be null&quot;);
     * </pre>
     * 
     * @param object
     *            the object to check is not <code>null</code>
     * @param message
     *            the exception message you would like to see if the object is <code>null</code>
     * @throws IllegalArgumentException
     *             if the object is <code>null</code>
     */
    public static void notNull(Object object, String message)
    {
        if (object == null)
        {
            throw new IllegalArgumentException(message);
        }
    }

    /**
     * <p>
     * Validate an argument, throwing <code>IllegalArgumentException</code> if the argument is
     * <code>null</code>.
     * </p>
     * 
     * <pre>
     * Validate.notNull(myObject);
     * </pre>
     * 
     * <p>
     * The message in the exception is 'The validated object is null'.
     * </p>
     * 
     * @param object
     *            the object to check is not <code>null</code>
     * @throws IllegalArgumentException
     *             if the object is <code>null</code>
     */
    public static void notNull(Object object)
    {
        if (object == null)
        {
            throw new IllegalArgumentException("The validated object is null");
        }
    }



    // notEmpty string
    // ---------------------------------------------------------------------------------

    /**
     * <p>
     * Validate an argument, throwing <code>IllegalArgumentException</code> if the argument String
     * is empty (<code>null</code> or zero length).
     * </p>
     * 
     * <pre>
     * Validate.notEmpty(myString, &quot;The string must not be empty&quot;);
     * </pre>
     * 
     * @param string
     *            the string to check is not empty
     * @param message
     *            the exception message you would like to see if the string is empty
     * @throws IllegalArgumentException
     *             if the string is empty
     */
    public static void notEmpty(String string, String message)
    {
        if (string == null || string.length() == 0)
        {
            throw new IllegalArgumentException(message);
        }
    }

    /**
     * <p>
     * Validate an argument, throwing <code>IllegalArgumentException</code> if the argument String
     * is empty (<code>null</code> or zero length).
     * </p>
     * 
     * <pre>
     * Validate.notEmpty(myString);
     * </pre>
     * 
     * <p>
     * The message in the exception is 'The validated string is empty'.
     * </p>
     * 
     * @param string
     *            the string to check is not empty
     * @throws IllegalArgumentException
     *             if the string is empty
     */
    public static void notEmpty(String string)
    {
        if (string == null || string.length() == 0)
        {
            throw new IllegalArgumentException("The validated string is empty");
        }
    }


}
