package ch.dvbern.stvbe.security.saml.util;

import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;

import org.w3c.dom.Node;

/**
 * Hilfsklasse fuer XPath Operationen
 * @author GEMA
 *
 */
public class XPathHelper {

	/**
	 * SOAP Envelope Prefix
	 */
	public static final String SOAPENV_PREFIX = "soapenv";

	/**
	 * SAML Prefix
	 */
	public static final String SAML_PREFIX = "saml";

	/**
	 * Web Service Security Prefix
	 */
	public static final String WSS_PREFIX = "wss";	

	/**
	 * Web Service Trust Prefix
	 */
	public static final String WST_PREFIX = "wst";	

	/**
	 * Digital Signature Prefix
	 */
	public static final String DSIG_PREFIX = "ds";
	
	private XPathHelper() {
	}
	
	/**
	 * Erstellt einen XPath
	 * @return den XPath
	 */
	public static XPath createXPath() {
		// XPath erstellen
		XPathFactory xPathFactory = XPathFactory.newInstance();
		XPath xPath = xPathFactory.newXPath();
		
		// Namespace prefixes registrieren
		NamespaceContextImpl nsCtx = new NamespaceContextImpl();
		nsCtx.bindPrefixToNamespaceURI(WSS_PREFIX, NsConstants.WSS);
		nsCtx.bindPrefixToNamespaceURI(WST_PREFIX, NsConstants.WST);
        nsCtx.bindPrefixToNamespaceURI(SAML_PREFIX, NsConstants.SAML);
        nsCtx.bindPrefixToNamespaceURI(DSIG_PREFIX, NsConstants.DSIG);
        nsCtx.bindPrefixToNamespaceURI(SOAPENV_PREFIX, NsConstants.SOAPENV);
		xPath.setNamespaceContext(nsCtx);
		
		return xPath;
	}
	
	/**
	 * Gibt den durch xpathExpr beschriebenen {@link Node} relativ zu {@link Node} n zurück.
	 * 
	 * @param xpathExpr XPath-Ausdruck
	 * @param n Node unter welchem nach dem gegebenen XPath-Ausdruck gesucht werden soll.
	 * @return den gefundenen Node, oder <code>null</code>
	 * @throws XPathExpressionException 
	 */
	public static Node selectNode(String xpathExpr, Node n) throws XPathExpressionException {
		return (Node) createXPath().evaluate(xpathExpr, n, XPathConstants.NODE);
	}
	

}
