package ch.dvbern.stvbe.security.saml.verify;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.opensaml.SAMLAssertion;

import ch.dvbern.stvbe.security.saml.util.SamlAssertionUtil;


/**
 * Basisklasse fuer einen SAML Assertion Verifier
 * @author GEMA
 */
public abstract class AbstractSamlAssertionVerifier implements SamlAssertionVerifier {

	private static Log log = LogFactory.getLog(AbstractSamlAssertionVerifier.class);
	
	private boolean allowUnauthenticated = false;
	
	/**
	 * Legt fest, ob ein Login ohne Assertion erlaubt ist
	 * @param allowUnauthenticated <code>true</code> falls ein Login ohne Assertion erlaubt ist
	 */
	public void setAllowUnauthenticated(boolean allowUnauthenticated) {
		this.allowUnauthenticated = allowUnauthenticated;
	}
	
	public boolean isAllowUnauthenticated() {
		return allowUnauthenticated;
	}
	
	
	/**
	 * Extrahiert die User ID aus dieser SAML Assertion
	 * @return die User ID
	 */
	@SuppressWarnings("unchecked")
	public String getUsername(SAMLAssertion assertion) {
		if (assertion == null) {
			return "<unauthenticated>";
		}
		
		String username = SamlAssertionUtil.getUsername(assertion);
		if (username == null) {
			log.warn("SAML Assertion contains no Username");
		}
		return username;
	}
	


}
