package ch.dvbern.stvbe.security.saml.wss4j;

import java.util.Map;
import java.util.Properties;
import java.util.Vector;

import org.apache.ws.security.handler.WSHandlerConstants;
import org.codehaus.xfire.security.wss4j.WSS4JInHandler;

/**
 * WSS4J Handler, welcher so konfiguriert werden kann, dass saemtlich Actions optional sind.
 * Falls der <code>"action"</code> Parameter auf <code>"OptionalSecurity"</code> gesetzt wird,
 * werden alle Actions optional ausgefuehrt. Andernfalls werden die Actions normal ausgefuehrt.
 * @author GEMA
 */
public class WSS4JOptionalInHandler extends WSS4JInHandler {

	/**
	 * Action Wert fuer Optionale Security.
	 */
	public static final String OPTIONAL_SECURITY = "OptionalSecurity";
	private boolean optionalEnabled = false;
	
	/**
	 * Konstruktor
	 */
	public WSS4JOptionalInHandler() {
		super();
	}

	/**
	 * Konstruktor
	 * @param properties die Properties
	 */
	public WSS4JOptionalInHandler(Properties properties) {
		super(properties);
	}

	@SuppressWarnings("unchecked")
	@Override
	protected boolean checkReceiverResults(Vector arg0, Vector arg1) {
		if (optionalEnabled) {
			return true;
		} else {
			return super.checkReceiverResults(arg0, arg1);
		}
	}
	
	@SuppressWarnings("unchecked")
	@Override
	public void setProperties(Map properties) {
		optionalEnabled = false;

		if (properties != null) {
			String action = (String)properties.get(WSHandlerConstants.ACTION);
			if (action != null && OPTIONAL_SECURITY.equals(action.trim())) {	
				properties.put(WSHandlerConstants.ACTION,WSHandlerConstants.NO_SECURITY);
				optionalEnabled = true;
			}
		}

		super.setProperties(properties);
	}

}
