package ch.dvbern.stvbe.security.saml.wss4j;

import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.ws.security.handler.WSHandlerConstants;
import org.apache.ws.security.saml.SAMLIssuer;
import org.apache.ws.security.saml.SAMLIssuerFactory;
import org.codehaus.xfire.security.wss4j.WSS4JOutHandler;

/**
 * WSS4J Handler, welcher die <code>"SamlTokenUnsigned"</code> Action mit einem
 * {@link PassthroughSamlIssuer} nur ausfuehrt, falls eine Assertion verfuegbar
 * ist (d.h. {@link PassthroughSamlIssuer#isAssertionAvailable()} gibt
 * <code>true</code> zurueck).
 * 
 * @author GEMA
 */
public class WSS4JOptionalOutHandler extends WSS4JOutHandler {

	private static final Log log = LogFactory
			.getLog(WSS4JOptionalOutHandler.class);

	/**
	 * Konstruktor
	 */
	public WSS4JOptionalOutHandler() {
		super();
	}

	/**
	 * Konstruktor
	 * @param properties die Properties
	 */
	public WSS4JOptionalOutHandler(Properties properties) {
		super(properties);
	}

	@Override
	public String getString(String key, Object ctx) {

		// Beim Action Wert wrid die SamlTokenUnsigned Action entfernt,
		// falls ein PassthroughSamlIssuer konfiguriert ist und dieser
		// keine Assertion liefern kann
		if (!WSHandlerConstants.ACTION.equals(key)) {
			return super.getString(key, ctx);
		}

		String action = super.getString(key, ctx);
		if (action.indexOf(WSHandlerConstants.SAML_TOKEN_UNSIGNED) < 0) {
			return action;
		}

		String propfile = getString(WSHandlerConstants.SAML_PROP_FILE, ctx);
		if (propfile == null) {
			return action;
		}

		SAMLIssuer saml = SAMLIssuerFactory.getInstance(propfile);
		if (!(saml instanceof PassthroughSamlIssuer)) {
			return action;
		}

		if (((PassthroughSamlIssuer) saml).isAssertionAvailable()) {
			return action;
		}

		log
				.debug("the PassthroughSamlIssuer has no assertion available. SamlTokenUnsigned action will not run.");
		action = action.replace(WSHandlerConstants.SAML_TOKEN_UNSIGNED, "");
		if (action.trim().length() == 0) {
			action = WSHandlerConstants.NO_SECURITY;
		}

		return action;

	}

}
